@@ -28,14 +28,12 @@ dict-like has_key(), keys(), and items() methods, as well as more specialist
 value(), set_value() and is_single_valued() methods for improved access to ALPHA
 and any other unindexed blocks.
 
-Please cite PySLHA via the URL http://insectnation.org/projects/pyslha if it is
-useful to you in the production of an academic paper. A PySLHA publication will
-be provided at some point... watch this space!
-
+If you use PySLHA, for either model data handling or spectrum visualisation,
+please cite the paper: http://arxiv.org/abs/1305.4194
 
 TODOs:
 
-  For 2.2.2:
+  For 2.1.3:
    * In set_value, if first item is non-int, treat as None-indexed
    * Refine value string heuristic for strings with ints in them?
 
@@ -51,7 +49,7 @@ TODOs:
 """
 
 __author__ = "Andy Buckley <andy.buckley@cern.ch>"
-__version__ = "2.1.1"
+__version__ = "2.1.2"
 
 
 
